Struct ubits::example::ExampleField
source · [−]pub struct ExampleField(_);Expand description
Optional docstring for my example bit field.
Implementations
sourceimpl ExampleField
impl ExampleField
Constant values describing ExampleField.
sourcepub const BITS: usize
pub const BITS: usize
Number of bits in an instance of ExampleField.
sourcepub const BYTES: usize
pub const BYTES: usize
Number of bytes used by an instance of ExampleField.
sourcepub const MAX: u8
pub const MAX: u8
Maximum valid integer for ExampleField.
sourceimpl ExampleField
impl ExampleField
Constructors for creating instances of ExampleField.
sourcepub fn new(value: u8) -> Self
pub fn new(value: u8) -> Self
Create a new instance of ExampleField from a u8 value.
sourcepub fn zeros() -> Self
pub fn zeros() -> Self
Create a new instance of ExampleField from 0.
sourcepub fn ones() -> Self
pub fn ones() -> Self
Create a new instance of ExampleField from the maximum possible integer value.
sourcepub fn from_binary_str(value: &str) -> Self
pub fn from_binary_str(value: &str) -> Self
Create a new instance of ExampleField from a binary string.
sourcepub fn from_binary_string(value: String) -> Self
pub fn from_binary_string(value: String) -> Self
Create a new instance of ExampleField from a binary string.
sourceimpl ExampleField
impl ExampleField
Current state of this bitfield.
sourceimpl ExampleField
impl ExampleField
Field accessors by index for ExampleField.
sourcepub fn get_index(&self, index: u8) -> bool
pub fn get_index(&self, index: u8) -> bool
Returns the value of the bit at the supplied index as a boolean.
sourcepub fn clear_index(&mut self, index: u8)
pub fn clear_index(&mut self, index: u8)
Sets the value of the bit at the supplied index to 0.
sourcepub fn toggle_index(&mut self, index: u8)
pub fn toggle_index(&mut self, index: u8)
Flips the value of the bit at the supplied index.
sourceimpl ExampleField
impl ExampleField
Named field accessors by ExampleFlags for ExampleField.
sourcepub fn get(&self, flag: ExampleFlags) -> bool
pub fn get(&self, flag: ExampleFlags) -> bool
Returns the value of the bit at the supplied flag as a boolean.
sourcepub fn set(&mut self, flag: ExampleFlags) -> &mut Self
pub fn set(&mut self, flag: ExampleFlags) -> &mut Self
Sets the value of the bit at the supplied flag to 1.
sourcepub fn clear(&mut self, flag: ExampleFlags) -> &mut Self
pub fn clear(&mut self, flag: ExampleFlags) -> &mut Self
Sets the value of the bit at the supplied flag to 0.
sourcepub fn toggle(&mut self, flag: ExampleFlags) -> &mut Self
pub fn toggle(&mut self, flag: ExampleFlags) -> &mut Self
Flips the value of the bit at the supplied flag.
sourceimpl ExampleField
impl ExampleField
Combinators for ExampleField.
sourcepub fn diff(&self, other: Self) -> Self
pub fn diff(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that do not match. Does not consume self.
sourcepub fn combine(&self, other: Self) -> Self
pub fn combine(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on either input. Does not consume self.
sourcepub fn intersect(&self, other: Self) -> Self
pub fn intersect(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on both inputs. Does not consume self.
sourceimpl ExampleField
impl ExampleField
Conversion methods.
sourcepub fn into_diff(self, other: Self) -> Self
pub fn into_diff(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that do not match. Consumes self.
sourcepub fn into_combined(self, other: Self) -> Self
pub fn into_combined(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on either input. Consumes self.
sourcepub fn into_intersection(self, other: Self) -> Self
pub fn into_intersection(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on both inputs. Consumes self.