pub struct ExampleField(/* private fields */);Expand description
Optional docstring for my example bit field.
Implementations
Sourceimpl ExampleField
Constant values describing ExampleField.
impl ExampleField
Constant values describing ExampleField.
Sourcepub const BITS: usize = 8
pub const BITS: usize = 8
Number of bits in an instance of ExampleField.
Sourcepub const BYTES: usize
pub const BYTES: usize
Number of bytes used by an instance of ExampleField.
Sourcepub const MAX: u8 = u8::MAX
pub const MAX: u8 = u8::MAX
Maximum valid integer for ExampleField.
Sourceimpl ExampleField
Constructors for creating instances of ExampleField.
impl ExampleField
Constructors for creating instances of ExampleField.
Sourcepub fn new(value: u8) -> Self
pub fn new(value: u8) -> Self
Create a new instance of ExampleField from a u8 value.
Sourcepub fn zeros() -> Self
pub fn zeros() -> Self
Create a new instance of ExampleField from 0.
Sourcepub fn ones() -> Self
pub fn ones() -> Self
Create a new instance of ExampleField from the maximum possible integer value.
Sourcepub fn from_binary_str(value: &str) -> Self
pub fn from_binary_str(value: &str) -> Self
Create a new instance of ExampleField from a binary string.
Sourcepub fn from_binary_string(value: String) -> Self
pub fn from_binary_string(value: String) -> Self
Create a new instance of ExampleField from a binary string.
Sourceimpl ExampleField
Current state of this bitfield.
impl ExampleField
Current state of this bitfield.
Sourceimpl ExampleField
Field accessors by index for ExampleField.
impl ExampleField
Field accessors by index for ExampleField.
Sourcepub fn get_index(&self, index: u8) -> bool
pub fn get_index(&self, index: u8) -> bool
Returns the value of the bit at the supplied index as a boolean.
Sourcepub fn clear_index(&mut self, index: u8)
pub fn clear_index(&mut self, index: u8)
Sets the value of the bit at the supplied index to 0.
Sourcepub fn toggle_index(&mut self, index: u8)
pub fn toggle_index(&mut self, index: u8)
Flips the value of the bit at the supplied index.
Sourceimpl ExampleField
Named field accessors by ExampleFlags for ExampleField.
impl ExampleField
Named field accessors by ExampleFlags for ExampleField.
Sourcepub fn get(&self, flag: ExampleFlags) -> bool
pub fn get(&self, flag: ExampleFlags) -> bool
Returns the value of the bit at the supplied flag as a boolean.
Sourcepub fn set(&mut self, flag: ExampleFlags) -> &mut Self
pub fn set(&mut self, flag: ExampleFlags) -> &mut Self
Sets the value of the bit at the supplied flag to 1.
Sourcepub fn clear(&mut self, flag: ExampleFlags) -> &mut Self
pub fn clear(&mut self, flag: ExampleFlags) -> &mut Self
Sets the value of the bit at the supplied flag to 0.
Sourcepub fn toggle(&mut self, flag: ExampleFlags) -> &mut Self
pub fn toggle(&mut self, flag: ExampleFlags) -> &mut Self
Flips the value of the bit at the supplied flag.
Sourceimpl ExampleField
Combinators for ExampleField.
impl ExampleField
Combinators for ExampleField.
Sourcepub fn diff(&self, other: Self) -> Self
pub fn diff(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that do not match. Does not consume self.
Sourcepub fn combine(&self, other: Self) -> Self
pub fn combine(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on either input. Does not consume self.
Sourcepub fn intersect(&self, other: Self) -> Self
pub fn intersect(&self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on both inputs. Does not consume self.
Sourceimpl ExampleField
Conversion methods.
impl ExampleField
Conversion methods.
Sourcepub fn into_diff(self, other: Self) -> Self
pub fn into_diff(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that do not match. Consumes self.
Sourcepub fn into_combined(self, other: Self) -> Self
pub fn into_combined(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on either input. Consumes self.
Sourcepub fn into_intersection(self, other: Self) -> Self
pub fn into_intersection(self, other: Self) -> Self
Returns a new ExampleFieldwith ones for flags that were set on both inputs. Consumes self.